# 常用函数包

-
    1. 项目根目录下必须包含config.py文件

- 支付接口编写规范：
  支付服务_代码规范.py

# 更细说明

- 1.0.69 : 更新 Errors.py中的异常码
- 1.0.70 : 阿里云 异步短信验证码接口.  注意: 阿里云SDK需单独安装, 安装包在需要用的功能文件中列出
- 1.0.71 : 调整异步短信接口命名 
  - SMS_发送短息ASYNC --> SMS_发送短信v2.py
  - "SMS_发送短信v2", 合并同步短信接口,统一使用阿里V2 SDK.
